Links Continuous Glucose Monitoring (CGM) Time Series Data with Person-Reported Hypoglycaemia (PRH) Data
Source:R/linkingFunctions.R
cgmprhLink.RdCreates a dataset containing longitudinal CGM time series data with PRH episodes on the same row as the closest (in time) CGM timestamps. To run this function, the PRH dataset must be first built using the prhLink function.